@@ -9,5 +9,5 @@
     unused_import_braces
 )]
 //! a library to parse markdown and convert it into sauron virtual node
-pub use markdown::{markdown, render_markdown};
+pub use markdown::{markdown, markdown_with_plugins, render_markdown, Plugins};
 mod markdown;
